;---------------------------------------------------------------------------------------------;
;
; example 2b (modified example 2)
; dual 6850 board - acia setup and serial transmission
;
; this version runs on systems with 4MB ROM, 8MB RAM, & ACIA @ $AC0000
;
; 25/10/2020 steve crompton
;
;---------------------------------------------------------------------------------------------;

ram_start           EQU $000000
rom_start           EQU $C00000
hex_display         EQU $AB0000
dual_6850_acia1     EQU $AC0000     ;con (term) + j1 pins 1-2 short
dual_6850_acia2     EQU $AC0001     ;aux (host) + j1 pins 1-2 short
dual_6850_acia3     EQU $AC0040     ;con (term) + j1 pins 2-3 short
dual_6850_acia4     EQU $AC0041     ;aux (host) + j1 pins 2-3 short

acia_cr             EQU 0           ;acia control register
acia_sr             EQU 0           ;acia status register
acia_tdr            EQU 2           ;acia transmit data register
acia_rdr            EQU 2           ;acia receive register
acia_tdre           EQU 1           ;acia sr - transmit data register empty bit

cr                  EQU 13          ;carriage return
lf                  EQU 10          ;line feed

acia_base_addr      EQU dual_6850_acia1

    ORG     rom_start

    DC.L    ram_start+$1000         ;reset: initial ssp
    DC.L    cold_boot               ;reset: initial pc

code:

    ORG     rom_start+$400

cold_boot:

    move.l #$12340000,d0            ;put "12340000" on the hex display
    move.l d0,hex_display           ;to indicate program start

    lea.l  acia_base_addr,a0        ;load the address of the acia into a0

    jsr acia_init                   ;reset/initialise the acia

    move.b #'H',d0                  ;send 'H'
    jsr acia_put
    move.b #'e',d0                  ;send 'e'
    jsr acia_put
    move.b #'l',d0                  ;send 'l'
    jsr acia_put
    move.b #'l',d0                  ;send 'l'
    jsr acia_put
    move.b #'o',d0                  ;send 'o'
    jsr acia_put
    move.b #' ',d0                  ;send ' '
    jsr acia_put
    move.b #'W',d0                  ;send 'W'
    jsr acia_put
    move.b #'o',d0                  ;send 'o'
    jsr acia_put
    move.b #'r',d0                  ;send 'r'
    jsr acia_put
    move.b #'l',d0                  ;send 'l'
    jsr acia_put
    move.b #'d',d0                  ;send 'd'
    jsr acia_put
    move.b #cr,d0                   ;send carriage return
    jsr acia_put
    move.b #lf,d0                   ;send line feed
    jsr acia_put

    move.l #$00005678,d0            ;put "00005678" on the hex display
    move.l d0,hex_display           ;to indicate program end

forever:

    bra forever                     ;wait for reset button to be pressed

;---------------------------------------------------------------------------------------------;

; subroutine:   acia_init

; description:  6850 acia - reset/initialise device routine
; purpose:      prepare device for use
; parameters:   a0.l - base address of the 6850 acia
; side effects:

acia_init:

    move.b #$03,(a0)                ;reset the acia
    move.b #$15,(a0)                ;configure the acia for:
                                    ;no interrupts
                                    ;8 data bits, no parity, 1 stop bit
                                    ;16x clock
    rts

;---------------------------------------------------------------------------------------------;

; subroutine:   acia_put

; description:  6850 acia - serial transmit routine
; purpose:      transmit a byte/character
; parameters:   a0.l - base address of the 6850 acia
;               d0.b - byte/character to send
; side effects:

acia_put:

;wait for empty transmit buffer

    btst.b #acia_tdre,acia_sr(a0)   ;read the status register
    beq.s acia_put                  ;tdre=1 when transmit buffer empty

    move.b d0,acia_tdr(a0)          ;transmit the byte/character in d0
    rts

;---------------------------------------------------------------------------------------------;

    END    code































*~Font name~Courier New~
*~Font size~10~
*~Tab type~1~
*~Tab size~4~
